@@ -51,7 +51,7 @@ class SyncKohaRowsCommand(BaseCommand):
                                               })
 
                 if post_rows_req.status_code is not 200:
-                    logger.warning(f"Request status was not 200 : {vars(post_rows_req)}")
+                    logger.warning(f"Request status was not 200 : {post_rows_req}")
 
                 # write last synchronized record date without timezone
                 LoadConfigFileCommand.set_last_record(records[-1]['tr_datetime'].split("+")[0])
